==> haskell-hjsmin-0.2.0.4-123-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hjsmin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hjsmin
version:              0.2.0.4
visibility:           public
id:                   hjsmin-0.2.0.4-HzO4QufBr4u2lXsfyzT1xH
key:                  hjsmin-0.2.0.4-HzO4QufBr4u2lXsfyzT1xH
license:              BSD-3-Clause
maintainer:           Erik de Castro Lopo <erikd@mega-nerd.com>
author:               Alan Zimmerman <alan.zimm@gmail.com>
stability:            unstable
homepage:             http://github.com/erikd/hjsmin
synopsis:             Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.

category:             Web
abi:                  cbe3675590f15bf35079a3bc0dbcfac3
exposed:              True
exposed-modules:      Text.Jasmine
import-dirs:          /usr/lib/ghc-9.0.1/site-local/hjsmin-0.2.0.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hjsmin-0.2.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/hjsmin-0.2.0.4
hs-libraries:         HShjsmin-0.2.0.4-HzO4QufBr4u2lXsfyzT1xH
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    language-javascript-0.7.1.0-IHxskCep5ffGvjuFzFqDBT text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html:         /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hjsmin-0.2.0.4-124-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hjsmin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hjsmin
version:              0.2.0.4
visibility:           public
id:                   hjsmin-0.2.0.4-8efqxjAyWbwFxtUiDzUlVF
key:                  hjsmin-0.2.0.4-8efqxjAyWbwFxtUiDzUlVF
license:              BSD-3-Clause
maintainer:           Erik de Castro Lopo <erikd@mega-nerd.com>
author:               Alan Zimmerman <alan.zimm@gmail.com>
stability:            unstable
homepage:             http://github.com/erikd/hjsmin
synopsis:             Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.

category:             Web
abi:                  0cf7097367f0a044e4b8677012e4e3eb
exposed:              True
exposed-modules:      Text.Jasmine
import-dirs:          /usr/lib/ghc-9.0.1/site-local/hjsmin-0.2.0.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hjsmin-0.2.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/hjsmin-0.2.0.4
hs-libraries:         HShjsmin-0.2.0.4-8efqxjAyWbwFxtUiDzUlVF
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    language-javascript-0.7.1.0-1oxFmHzeY32BaRx2g9VwSw text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html:         /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
